@@ -269,7 +269,8 @@ class Service(object):
 
     # Delegated list methods
 
-    LIST_MANAGER_METHODS = frozenset(["get_list", "get_all_lists", "get_all_list_names",
+    LIST_MANAGER_METHODS = frozenset(["get_list", "get_all_lists", 
+        "get_all_list_names",
         "create_list", "get_list_count", "delete_lists", "l"])
 
     def __getattribute__(self, name):
