@@ -319,6 +319,38 @@ class LiveListTest(unittest.TestCase):
         self.assertEqual(emp_rows_without_ids(listA), expected)
         self.assertEqual(prev_name, listA.name)
         self.assertEqual(prev_desc, listA.description)
+        
+        # Test subqueries
+        with_cc_q = s.model.Bank.where("corporateCustomers.id", "IS NOT NULL")
+        with_cc_l = s.create_list(with_cc_q)
+
+        self.assertEqual(2, s.model.Bank.where(s.model.Bank ^ with_cc_q).count())
+        self.assertEqual(2, s.model.Bank.where(s.model.Bank ^ with_cc_l).count())
+
+        self.assertEqual(3, s.model.Bank.where(s.model.Bank < with_cc_q).count())
+        self.assertEqual(3, s.model.Bank.where(s.model.Bank < with_cc_l).count())
+
+        boring_q = s.new_query("Bank")
+        boring_q.add_constraint("Bank", "NOT IN", with_cc_q)
+        self.assertEqual(2, boring_q.count())
+
+        boring_q = s.new_query("Bank")
+        boring_q.add_constraint("Bank", "NOT IN", with_cc_l)
+        self.assertEqual(2, boring_q.count())
+
+        # Test query overloading
+
+        no_comps = s.new_query("Bank") - with_cc_q
+        self.assertEqual(2, no_comps.size)
+
+        no_comps = s.new_query("Bank") - with_cc_l
+        self.assertEqual(2, no_comps.size)
+
+        all_b = s.new_query("Bank") | with_cc_q
+        self.assertEqual(5, all_b.size)
+
+        all_b = s.new_query("Bank") | with_cc_l
+        self.assertEqual(5, all_b.size)
 
     def tearDown(self):
         s = self.SERVICE
